#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 validity-bytestring
version:              0.4.1.1
visibility:           public
id:                   validity-bytestring-0.4.1.1-5fKsytHifuNDCX9o4Wpm7i
key:                  validity-bytestring-0.4.1.1-5fKsytHifuNDCX9o4Wpm7i
license:              MIT
copyright:            Copyright: (c) 2016-2020 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Validity instances for bytestring
description:          Please see README.md
category:             Validity
abi:                  2f88b697e7cb779f8a8e91e4d530bf2c
exposed:              True
exposed-modules:      Data.Validity.ByteString
hidden-modules:       Paths_validity_bytestring
import-dirs:          /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/validity-bytestring-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-validity-bytestring
hs-libraries:         HSvalidity-bytestring-0.4.1.1-5fKsytHifuNDCX9o4Wpm7i
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    validity-0.12.1.0-LG2b2RIsvUr3DYuhRAUiQY

haddock-interfaces:
    /usr/share/doc/haskell-validity-bytestring/html/validity-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-validity-bytestring/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

